# -*- coding: utf8 -*-
'''
DB MODULE - Firebird
*******************************
***  DB MODULE - Firebird
*******************************
$RCSfile: dbmod_firebird.py,v $
$Revision: 1341 $
$Author: j.holetschek $
$Date: 2014-01-28 10:42:22 +0100 (Di, 28. Jan 2014) $

The biocase.wrapper database module to access Firebird/Interbase databases.
You will need the kinterbasdb python module to run this dbmodule.
'''

from string import join
from biocase.wrapper.dbmod.base_dbmod import DBBasemodule
from biocase.wrapper.sql.base import sqlBase
from biocase.wrapper.errorclasses import DbModuleMissingError, ConnectionError

import logging
log = logging.getLogger("pywrapper.dbmod")

# no alias tag
sqlBase.templates['alias'] = '#1  #2'

# OFFSET: SELECT FIRST x SKIP y * FROM
sqlBase.templates['select-limit'] = 'SELECT FIRST #3 DISTINCT #1 FROM #2'
sqlBase.templates['select-limit-offset'] = 'SELECT FIRST #3 SKIP #4 DISTINCT #1 FROM #2'


class DBmodule(DBBasemodule):
    __version__ = '1.0 using kinterbasedb ?'
    __dbmod__ = u'Firebird module'

    def __init__(self, psfObj):
                # call createDBconnection method
        DBBasemodule.__init__(self, psfObj)

        # read DB 8bit encoding
        log.debug("8bit DB Encoding: %s" % psfObj.encoding)
        self.conn.encoding = psfObj.encoding

    def createDBconnection(self):

        # import
        try:
            import kinterbasdb
            self.__class__.__version__ = self.__class__.__version__[:-1] + join([str(v) for v in kinterbasdb.__version__], '.')
        except:
            raise DbModuleMissingError('kinterbasdb')

        # connect
        try:
            if self.psfObj.password:
                return kinterbasdb.connect(host=str(self.psfObj.dbIP), user=str(self.psfObj.user), database=str(self.psfObj.database), password=str(self.psfObj.password))
            else:
                return kinterbasdb.connect(host=str(self.psfObj.dbIP), user=str(self.psfObj.user), database=str(self.psfObj.database))
        except:
            raise ConnectionError()

    def execSQL(self, sql, paras=None):
        if paras is not None:
            # only allow strings as parameters, not unicode
            p_tmp = []
            for p in paras:
                if type(p) == unicode:
                    p = p.encode(self.conn.encoding)
                p_tmp.append(p)
            paras = p_tmp
        # call base method
        return DBBasemodule.execSQL(self, sql, paras)

    def getTables(self):
        tables = []
        self.c = self.conn.cursor()
        try:
            self.c.execute("select rdb$relation_name from rdb$relations where rdb$system_flag = 0")
            for t in self.c.fetchall():
                tables.append(t[0].strip())
        except Exception, ex:
            log.error("Couldn't retrieve table list: %s." % ex)
        finally:
            self.c.close()
        return tables

    def getColumns(self, _table):
        columns = []
        self.c = self.conn.cursor()
        try:
            self.c.execute("select rdb$field_name from rdb$relation_fields where rdb$relation_name = '%s'" % (_table))
            for c in self.c.fetchall():
                columns.append(c[0].strip())
        except:
            log.error("Couldn't retrieve column info for table " + _table)
        finally:
            self.c.close()
        return columns

    def hasMetaInfo(self):
        return True
