# -*- coding: utf8 -*-
'''
DB MODULE - ODBC Firebird
*******************************
***  DB MODULE - ODBC Firebird
*******************************
$RCSfile: dbmod_odbc_firebird.py,v $
$Revision: 1556 $
$Author: j.holetschek $
$Date: 2018-04-27 10:04:32 +0200 (Fr, 27. Apr 2018) $

The biocase.wrapper database module to access Firebird trough ODBC datasources.
You will need the mxODBC module to connect to a DSN via ODBC.
'''

from biocase.wrapper.errorclasses import DbModuleMissingError, ConnectionError
from biocase.wrapper.sql.base import sqlBase
from biocase.wrapper.dbmod.base_dbmod import DBBasemodule

import logging
log = logging.getLogger("pywrapper.dbmod")

# no alias tag
sqlBase.templates['alias'] = '#1  #2'

# OFFSET: SELECT FIRST x SKIP y * FROM
sqlBase.templates['select-limit'] = 'SELECT FIRST #3 DISTINCT #1 FROM #2'
sqlBase.templates['select-limit-offset'] = 'SELECT FIRST #3 SKIP #4 DISTINCT #1 FROM #2'


# sqlBase.templates['attribute'] = '"#1"."#2"'
# sqlBase.templates['table'] = '"#1"'


class DBmodule(DBBasemodule):
    __version__ = ''
    __dbmod__ = u'Firebird using '


    def __init__(self, psfObj):
        # setting the psfObj reference to self.psfObj
        # call createDBconnection method
        DBBasemodule.__init__(self, psfObj)

    def createDBconnection(self):
        # import
        try:
            import pyodbc as odbc
            self.__class__.__dbmod__ += "pyODBC"
        except:
            try:
                import ceODBC as odbc
                self.__class__.__dbmod__ += "ceODBC"
            except:
                raise DbModuleMissingError('ceODBC/pyODBC')

        # connect
        try:
            loginParas = "DSN=%s;UID=%s" % (self.psfObj.database, self.psfObj.user)
            if self.psfObj.password:
                loginParas += ";PWD=%s" % self.psfObj.password
            return odbc.connect(loginParas)
        except:
            raise ConnectionError()

    def getTables(self):
        tables = []
        self.c = self.conn.cursor()
        try:
            self.c.execute("select rdb$relation_name from rdb$relations where rdb$system_flag = 0")
            for t in self.c.fetchall():
                tables.append(t[0].strip())
        except Exception, ex:
            log.error("Couldn't retrieve table list: %s." % ex)
        finally:
            self.c.close()
        return tables

    def getColumns(self, _table):
        columns = []
        self.c = self.conn.cursor()
        try:
            self.c.execute("select rdb$field_name from rdb$relation_fields where rdb$relation_name = '%s'" % (_table))
            for c in self.c.fetchall():
                columns.append(c[0].strip())
        except:
            log.error("Couldn't retrieve column info for table " + _table)
        finally:
            self.c.close()
        return columns

    def hasMetaInfo(self):
        return True
