# -*- coding: utf8 -*-
'''
******************************
***  DB MODULE - Text/ODBC
******************************
$RCSfile: dbmod_odbc_text.py,v $
$Revision: 1303 $
$Author: j.holetschek $
$Date: 2013-07-08 14:27:49 +0200 (Mo, 08 Jul 2013) $
'''

from biocase.wrapper.errorclasses import DbModuleMissingError, ConnectionError
from biocase.wrapper.sql.base import sqlBase
from biocase.wrapper.dbmod.base_dbmod import DBBasemodule

import logging
log = logging.getLogger("pywrapper.dbmod")

# uses inherited ANSI SQL apart from the following.
sqlBase.templates['attribute'] = '[#1].[#2]'
sqlBase.templates['join'] = '(#1 LEFT JOIN #2 ON #3)'
sqlBase.templates['select-limit'] = 'SELECT DISTINCT TOP #3 #1 FROM #2'
sqlBase.templates['alias'] = '[#1] AS [#2]'

# ESCAPE CHARACTERS
# -----------------
# characters that need to be escaped in SQL
# default list contains single quotes to be escaped into two single quotes
# but that's already done by ceODBC
sqlBase.escape = {}
	
class DBmodule(DBBasemodule):
    __version__ = ''
    __dbmod__ = u'ODBC text file module using '

    def createDBconnection(self):
        try:
            import pyodbc as odbc
            self.__class__.__dbmod__ += "pyODBC"
        except:
            try:
                import ceODBC as odbc
                self.__class__.__dbmod__ += "ceODBC"
            except:
                raise DbModuleMissingError('ceODBC/pyODBC')

        self.__class__.__version__ = odbc.version
        loginParas = "DSN=%s;UID=%s;PWD=%s" % (self.psfObj.database, self.psfObj.user , self.psfObj.password)
        try:
            # autocommit needs to be true
            return odbc.connect(loginParas, autocommit=True)
        except Exception, ex:
            log.exception(ex)
            raise ConnectionError

    def getTables(self):
        obj = self.conn if self.__dbmod__.endswith('ceODBC') else self.conn.cursor()
        return [t[2] for t in obj.tables()]

    def getColumns(self, table_name):
        obj = self.conn if self.__dbmod__.endswith('ceODBC') else self.conn.cursor()
        return [c[3] for c in obj.columns(table = table_name)]

    def hasMetaInfo(self):
        return True
