# -*- coding: utf8 -*-
'''
DB MODULE - ODBC for TSQL
*******************************
***  DB MODULE - ODBC for TSQL
*******************************
$RCSfile: dbmod_odbc_tsql.py,v $
$Revision: 1558 $
$Author: j.holetschek $
$Date: 2018-05-08 13:17:19 +0200 (Di, 08. Mai 2018) $

The biocase.wrapper database module to access MS SQL Server databases.
You will need the mxODBC module to connect to a MS SQL Server DB via ODBC.
'''

from biocase.wrapper.sql.base import sqlBase
from biocase.wrapper.dbmod.base_dbmod import DBBasemodule
from biocase.wrapper.errorclasses import DbModuleMissingError, ConnectionError

import logging
log = logging.getLogger("pywrapper.dbmod")


#############################################
#
# CUSTOMIZATION for SQL Server
#
# OVERLOAD BASE CLASSES AND OTHER METHODS
#
#############################################

# uses inherited ANSI SQL apart from the following.
sqlBase.templates['attribute'] = '[#1].[#2]'
sqlBase.templates['table'] = '[#1]'
sqlBase.templates['select-limit'] = 'SELECT DISTINCT TOP #3 #1 FROM #2'
sqlBase.templates['count-distinct'] = 'COUNT(DISTINCT #1)'

# Works only with SQL Server 2012 (or later)
# sqlBase.templates['select-limit-offset'] = 'SELECT DISTINCT #1 FROM #2 OFFSET #4 ROWS FETCH NEXT #3 ROWS ONLY'

# ESCAPE CHARACTERS
# -----------------
# characters that need to be escaped in SQL
# default list contains single quotes to be escaped into two single quotes
# but that's already done b< ceODBC
sqlBase.escape = {}

# For the subquery workaround, several other files need to be adapted
#
# wrapper/sql/base.py: Neues, leeres Template definieren
#   + 53    templates['select-limit-offset-subquery'] = None
#
# wrapper/sql/select.py: Neues Template anwenden. Zeilen 99 - 102 ersetzen durch:
#                if offset > 0 and (sqlBase.templates['select-limit-offset'] or sqlBase.templates['select-limit-offset-subquery']):
#                    if sqlBase.templates['select-limit-offset']:
#                        sql = self.apply_template('select-limit-offset', [sql_select, sql, limit + 1, offset])
#                    else:
#                        sql = self.apply_template('select-limit-offset-subquery', [sql_select, sql, limit + 1, offset])
#                else:
#                    sql = self.apply_template('select-limit', [sql_select, sql, limit + 1])
#
# wrapper/operations.py: Neuer Sonderfall für neues Template in "_getSearchResultList".
# - In Zeile 346 (nach dem Fall "elif sqlBase.templates['select-limit-offset'] != None") einfuegen:
#                elif sqlBase.templates['select-limit-offset-subquery'] != None:
#                    # DB doesn't support limit/offset, but there is a workaround with a subquery (like SQL Server)
#                    # order by list needs to be empty for this
#                    AllIDs = self.fixAllIds([ item[0] for item in self.execSelect([recID], self.requestObj.filter, orderByList=[], limit=limit, offset=start)])
# - Zeile 357 (if sqlBase.templates['select-limit-offset'] != None) ersetzen durch:
#     if sqlBase.templates['select-limit-offset'] != None or sqlBase.templates['select-limit-offset-subquery'] != None
#
# wrapper/protocol/BioCASe/biocase_response.py: Korrektur von totalSearchHits in postprocess:
# Zeile 95 (if sqlBase.templates['select-limit-offset']) ersetzen durch:
#     if sqlBase.templates['select-limit-offset'] or sqlBase.templates['select-limit-offset-subquery']
#
# archive/archive.py: Korrektur von totalSearchHits (da postprocess von biocase_response nicht verwendet wird):
# "if sqlBase.templates['select-limit-offset']" ersetzen durch
#   if sqlBase.templates['select-limit-offset'] or sqlBase.templates['select-limit-offset-subquery']
#
# Last: uncomment the following line
# sqlBase.templates['select-limit-offset-subquery'] = 'SELECT * FROM ( SELECT #1, ROW_NUMBER() OVER (ORDER BY #1) AS RowNum FROM #2) as tmp WHERE tmp.RowNum>#4 AND tmp.RowNum<=#3+#4'

class DBmodule(DBBasemodule):
    __version__ = ''
    __dbmod__ = u'MS SQL Server module using '

    def __init__(self, psfObj):
        # setting the psfObj reference to self.psfObj
        # call createDBconnection method
        DBBasemodule.__init__(self, psfObj)
        # dont use parameters but integrate all parameters into SQL strings:
        self.trans.integrateParametersInSQLString()

    # ------------------   FUNCTION OVERLOAD OF BASE DBMOD MODULE   ------------------
    def createDBconnection(self):
        try:
            import pyodbc as odbc
            self.__class__.__dbmod__ += "pyODBC"
        except:
            try:
                import ceODBC as odbc
                self.__class__.__dbmod__ += "ceODBC"
            except:
                raise DbModuleMissingError('ceODBC/pyODBC')

        self.__class__.__version__ = odbc.version
        loginParas = "DSN=%s;UID=%s;PWD=%s" % (self.psfObj.database, self.psfObj.user , self.psfObj.password)
        try:
            return odbc.connect(loginParas)
        except:
            raise ConnectionError()

    def getTables(self):
        tables = []
        obj = self.conn if self.__dbmod__.endswith('ceODBC') else self.conn.cursor()
        for t in obj.tables():
            if (str(t[3]) == 'TABLE' or str(t[3]) == 'VIEW') and not (t[1] in ["INFORMATION_SCHEMA", "sys"] or t[2] in ["dtproperties", "sysconstraints", "syssegments"]):
                tables.append(unicode(t[2]))
        return tables

    def getColumns(self, _table):
        try:
            obj = self.conn if self.__dbmod__.endswith('ceODBC') else self.conn.cursor()
            ret = [unicode(c[3]) for c in obj.columns(catalog=None, schema=None, table=_table)]
            if ret == None:
                return []
            return ret
        except:
            log.error("error fetching columns")
            return []

    def hasMetaInfo(self):
        return True
