# -*- coding: utf8 -*-
'''
DB MODULE - generic ODBC
*******************************
***  DB MODULE - generic ODBC
*******************************
$RCSfile: dbmod_sqlite.py,v $
$Revision: 1580 $
$Author: j.holetschek $
$Date: 2018-08-23 12:55:40 +0200 (Do, 23. Aug 2018) $

The biocase.wrapper database module to access generic ODBC datasources.
You will need the mxODBC module to connect to a DSN via ODBC.
'''

from biocase.wrapper.errorclasses       import ConnectionError, DbModuleMissingError
from biocase.wrapper.dbmod.base_dbmod   import DBBasemodule

import logging, os
log = logging.getLogger("pywrapper.dbmod_sqlite")

# Get configuration
import biocase.configuration
cfg = biocase.configuration.Cfg()

# uses inherited ANSI SQL


# ---------------------------------------------------------------------------------
# ---------------------------------------------------------------------------------
# ---------------------------------------------------------------------------------
class DBmodule(DBBasemodule):
    __dbmod__ = 'sqlite module using sqlite3 '

    def __init__(self, psfObj):
        # call createDBconnection method
        DBBasemodule.__init__(self, psfObj)

    def createDBconnection(self):
        try:
            import sqlite3
        except:
            raise DbModuleMissingError('sqlite3')
        self.__class__.__version__ = sqlite3.version

        try:
            # The filename from config is relative to the biocase root dir
            fname = os.path.join(cfg.homeLocator, self.psfObj.database)
            return sqlite3.connect(database=fname)
        except:
            raise ConnectionError

    def getTables(self):
        try:
            cur = self.conn.cursor()
            cur.execute("SELECT name FROM sqlite_master WHERE type in ('table', 'view')")
            return [r[0] for r in cur.fetchall()]
        except:
            log.exception("Couldn't retrieve table list")
        finally:
            cur.close()

    def getColumns(self, table):
        try:
            cur = self.conn.cursor()
            cur.execute("pragma table_info(%s)" % table)
            return [r[1] for r in cur.fetchall()]
        except:
            log.exception("Couldn't retrieve column list for table %s" % table)
        finally:
            cur.close()

    def hasMetaInfo(self):
        return True
