# -*- coding: utf8 -*-
'''
DB MODULE - SYBASE
*******************************
***  DB MODULE - SYBASE
*******************************
$RCSfile: dbmod_sybase.py,v $
$Revision: 1352 $
$Author: j.holetschek $
$Date: 2014-04-01 13:55:45 +0200 (Di, 01. Apr 2014) $

The biocase.wrapper database module to access Sybase databases.
You will need the Sybase module from http://www.object-craft.com.au/projects/sybase/ to connect.
'''

from biocase.wrapper.errorclasses import DbModuleMissingError
from biocase.wrapper.sql.base import sqlBase
from biocase.wrapper.dbmod.base_dbmod import DBBasemodule

import logging
log = logging.getLogger("pywrapper.dbmod")


#############################################
#
# CUSTOMIZATION for Sybase T-SQL
#
# OVERLOAD BASE CLASSES AND OTHER METHODS
#
#############################################


# uses inherited ANSI SQL apart from the following.
sqlBase.templates['attribute'] = '[#1].[#2]'
sqlBase.templates['table'] = '[#1]'
sqlBase.templates['select-limit'] = 'SELECT DISTINCT TOP #3 #1 FROM #2'
sqlBase.templates['count-distinct'] = 'COUNT(DISTINCT #1)'


# ---------------------------------------------------------------------------------
# ---------------------------------------------------------------------------------
# ---------------------------------------------------------------------------------
class DBmodule(DBBasemodule):
    __version__ = '0.9 using Sybase ?'
    __dbmod__ = u'Sybase module'

    # _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
    def __init__(self, psfObj):
        # setting the psfObj reference to self.psfObj
        # call createDBconnection method
        DBBasemodule.__init__(self, psfObj)

        # dont use parameters but integrate all parameters into SQL strings:
        self.trans.integrateParametersInSQLString()

    # _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
    def createDBconnection(self):
        try:
            import Sybase
        except:
            raise DbModuleMissingError('Sybase')
        self.__class__.__version__ = self.__class__.__version__[:-1] + Sybase.__version__
        #
        # connect
        #
        conn = Sybase.connect(self.psfObj.dbIP, self.psfObj.user, self.psfObj.password, self.psfObj.database)
        return conn

    # _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
    def getTables(self):
        tables = []
        self.c = self.conn.cursor()
        self.c.execute("SELECT name FROM sysobjects where type in ('U', 'V')")
        for t in self.c.fetchall():
            tables.append(str(t[0]))
        self.c.close()
        return tables

    def getColumns(self, _table):
        columns = []
        self.c = self.conn.cursor()
        try:
            self.c.execute("SELECT sc.name FROM syscolumns sc INNER JOIN sysobjects so ON sc.id = so.id WHERE so.name = '%s'" % (_table))
            for c in self.c.fetchall():
                columns.append(str(c[0]))
        except:
            log.error("Couldn't retrieve column info for table " + _table)
        finally:
            self.c.close()
        return columns

    def hasMetaInfo(self):
        return True
