# -*- coding: utf8 -*-
'''
**********************************************
*       P R O T O C O L - C L A S S
*       for the Dataset Inventory
**********************************************
$RCSfile: biocase_protocol.py,v $
$Revision: 1446 $
$Author: j.holetschek $
$Date: 2015-09-07 13:10:53 +0200 (Mo, 07. Sep 2015) $
'''

from biocase.wrapper.protocol.base_protocol import ProtocolBaseClass
from biocase.wrapper.protocol.BioCASe.biocase_request  import RequestClass
from biocase.wrapper.protocol.inventory.inventory_response import ResponseClass
from biocase.wrapper.errorclasses import NamespaceNotSupportedForDatasetInventory, InvalidNamespaceForDatasetInventory
from biocase.archive.general import ns_dataset_aware
from cgi import FieldStorage

import logging
log = logging.getLogger("pywrapper.protocol.inventory")

# ------------------------------------------------------------------------------------
class ProtocolClass(ProtocolBaseClass):
    NAME = "Dataset Inventory"

    # _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
    def __init__(self, dsaObj, diagnosticsHandler):
        # Note: the request object will be a regular BioCASe request object, since we will need that later for the Scan request
        # Only protocol and response objects are of inventory type!
        ProtocolBaseClass.__init__(self, dsaObj, diagnosticsHandler, RequestClass=RequestClass, ResponseClass=ResponseClass)
        self.datasets = []

    # _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
    def parseRequest(self, args):
        # First, try to find namespace parameter
        if type(args) == str:
            self.ns = args
        else:
            querystring = FieldStorage()
            if 'ns' in  querystring.keys():
                self.ns = querystring.getfirst('ns')
            else:
                # Schema: If it's empty when called directly, find the most likely schema
                log.info('Namespace parameter for dataset inventory not found; trying to find the most likely schema.')
                datasetaware_schemas = [s.NS for s in self.dsaObj.getSchemaListObj() if s.NS in ns_dataset_aware]
                if datasetaware_schemas:
                    self.ns = str(datasetaware_schemas[0])
                    log.info('Namespace parameter for dataset inventory set to %s.' % self.ns)
                else:
                    self.ns = None
                    log.error('No dataset-aware schema mapped for this datasource.')

        # Set the request as a scan on dataset title
        reqString = """<?xml version='1.0' encoding='UTF-8'?>
            <request xmlns='http://www.biocase.org/schemas/protocol/1.3'>
                <header><type>scan</type></header>
                <scan>
                    <requestFormat>%s</requestFormat>
                    <concept>/DataSets/DataSet/Metadata/Description/Representation/Title</concept>
                </scan>
            </request>""" % (self.ns)
        self.requestObj.parseRequest({'request_string': reqString})
        log.debug(self.requestObj)

    # _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
    def processRequest(self):
        # First, check namespace
        if self.ns in ns_dataset_aware:
            if self.ns in self.psfObj.schemas:
                log.info("Dataset Inventory for namespace %s requested. Executing Scan on Dataset Title." % (self.ns))
            else:
                raise NamespaceNotSupportedForDatasetInventory(self.ns)
        else:
            raise InvalidNamespaceForDatasetInventory(self.ns)

        # chose DBmodule, connect to DB
        from biocase.wrapper.operations import getOperationsObjectForDBMod
        operationObj = getOperationsObjectForDBMod(self.psfObj, self.responseObj)
        # Execute scan
        self.datasets = [d for d in operationObj.scan(self.requestObj) if d is not None]
        # Construct Inventory
        self.responseObj.setInventoryContent(self.datasets)
