/*
	Javascript for collapsing/expanding the concepts in the BioCASe mapping 

	developed by Falko Gloeckler (falko.gloeckler@mfn-berlin.de)
	Biodiversity Informatics, GBIF-D
	Museum fuer Naturkunde Berlin, Germany

	2013-06-17

*/	

/*
	Function to callapse a single concept 

	@param button		the button which fires the event to collapse
				in the HTML implementation he button must be a child in the DIV element "tree_header"
*/
	collapse = function(button) {
	
		button = $(button);
		var div = $(button.parent());		// get the element which should be collapsed
		div.attr("collapsed","true");		// indicate status by adding/changing an attribute

		var div_level = getIndentNumber(div);	// count the indents for the hierarchy
		var comp_div = $(div.next());		// get the next element for comparison
		var comp_level = getIndentNumber(comp_div);	// count the indents for the hierarchy
		while(div_level < comp_level)		
		{
			// hide the element if it is a child of the element collapsed
			comp_div.css({"display":"none"});
	
			// get next to repeat until a higher rank is reached
			comp_div = $(comp_div.next());
			comp_level = getIndentNumber(comp_div);
		}
	
		// change the button to enable expansion of the collapsed element
		button.html("+ ");
		//button.attr("title","expand");
	}
	


/*
	Function to collapse all concepts at once
*/
	collapse_all = function() {
		// get all buttons to fire the events
		$(".button").each(function(){
			collapse($(this));
		});	
	}

	
/* 
	Function to toggle the click event
*/
	collapse_expand = function(button) {
		button = $(button);
		if(button.html()=="- ")
			collapse(button);
		else
		if(button.html()=="+ ")
			expand(button);
	}
	
	
	
/*	
	Function to expand a single concept 

	@param button
		type:		tag element or jQuery object of an element
		description:	the button which fires the event to expand
				in the HTML implementation he button must be a child in the DIV element "tree_header"

	@param allChilds	
		type:		boolean
		description:	set to true, if all child elements of the expanded parent should be expanded, too
				(this is at least necessary for the function expand_all()
*/
	expand = function(button, allChilds) {
	
		button = $(button);
		var div = $(button.parent());		// get the element which should be expanded
		div.attr("collapsed","false");		// indicate status by adding/changing an attribute

		var div_level = getIndentNumber(div);	// count the indents for the hierarchy
		var comp_div = $(div.next());		// get the next element for comparison
		var comp_level = getIndentNumber(comp_div);	// count the indents for the hierarchy
		var child_level = div_level;
		var aboveLevelCollapse = false;
		var recursiveLevel = new Array();	// array for remembering the rank above 
		recursiveLevel[0] = div_level;
		var r = 0;
		while(div_level < comp_level)
		{
			if(allChilds==="true")
			{
				// show the element if it is a child of the element collapsed
				comp_div.css({"display":""});
			}else
			{

				if(aboveLevelCollapse===false)
				{
					// show the child element and check wheather it is collapsed its own
					if(comp_div.attr("collapsed")==="true")
					{
						child_level = comp_level+1;
						r = r+1;
						recursiveLevel[r] = comp_level;
						aboveLevelCollapse = true;					
					}
					comp_div.css({"display":""});
				}else
					if((comp_level < child_level))	// show the child element if the parent is not collapsed its own
					{
						if(comp_level <= recursiveLevel[r])	// check wheather the collapsed child element end 
						{
							aboveLevelCollapse = false;
							r = r-1;			
						}
					// show the child element and check wheather it is collapsed its own
					if(comp_div.attr("collapsed")==="true")
					{
						child_level = comp_level+1;
						r = r+1;
						recursiveLevel[r] = comp_level;
						aboveLevelCollapse = true;	
					}
					comp_div.css({"display":""});					}
			}

			// get next to repeat until a higher rank is reached
			comp_div = $(comp_div.next());
			comp_level = getIndentNumber(comp_div);
		}
		
		// change the button to enable collapsing of the expanded element
		button.html("- ");
		//button.attr("title","collapse");
	}


/*
	Function to expand all concepts at once
*/
	expand_all = function() {
		// get all buttons to fire the events
		$(".button").each(function(){
			expand($(this), 1);
		});	
	}


	collapse_unmapped = function() {
		// collapse only nodes that have no mappings
		$(".button").each(function() {
			if ($(this).attr("has_mapping")==="0")
				collapse($(this))
		});
	}

/*
	Function to count the number of indents to get an idea of the hierarchy

	@param div
		type:		tag element or jQuery object of an element
		description:	element which contains the indentation elements
*/
	getIndentNumber = function(div){
		var par = $(".tree_indentation", $(div));
		return $(".tree_single_indent", par).length;
	}

	
	
	// collapse all unmapped concepts by default on loading (if show all concepts mapped is checked)
	onload = function() {
		if (document.getElementsByName('show_all_concepts')[0].checked)
			collapse_unmapped()
	}